@@ -1220,7 +1220,7 @@ class MBIODevices(Items):
 
     def getByAddress(self, address):
         try:
-            return self._itemByAddress[address]
+            return self._itemByAddress[int(address)]
         except:
             pass
 
