@@ -90,6 +90,23 @@ class MBIOValue(object):
     def timeout(self, delay):
         return time.time()+delay
 
+    def checkIfValueWillTriggerNotify(self, v):
+        if v is not None:
+            try:
+                if type(self._value) is bool:
+                    if v != self._value:
+                        return True
+                    return False
+                if self._resolution is not None:
+                    if abs(self._value-v)>=self._resolution:
+                        return True
+                    return False
+                if v!=self._value:
+                    return True
+            except:
+                pass
+        return False
+
     def checkNotify(self):
         if not self._enableNotify:
             return False
@@ -460,8 +477,11 @@ class MBIOValue(object):
         return self.parent.units.str(self.unit)
 
     def isDigital(self):
-        if self.parent.units.isDigital(self.unit):
-            return True
+        # FIXED: a value is digital only if the object is a MBIODigitalValue instance
+        # and not by it's unit. Otherwise, in case an analog value is falsy written with a digital unit,
+        # the value object tends to be locked in a digital value.
+        # if self.parent.units.isDigital(self.unit):
+            # return True
         return False
 
     def isMultistate(self):
